░█▀▀▀█ ░█▄─░█ ▀▀█▀▀ █▀▄▀█ ░█▀▀▀█ ░█▄─░█ ▀▀█▀▀<br>
░█──░█ ░█░█░█ ─░█── █─▀─█ ░█──░█ ░█░█░█ ─░█──<br>
░█▄▄▄█ ░█──▀█ ─░█── ▀───▀ ░█▄▄▄█ ░█──▀█ ─░█──<br>
<br>
This is a package for analyzing split reads from ONT (Oxford Nanopore Technologies) alignment data. 

## Usage
Please refer to the docstrings for now. Will be updating readme and docs in the coming weeks.
